==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/language/1/barnraiser_01/fil_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_add_file'] = 						"add file";
$lang['hdr_files'] = 							"files";
$lang['hdr_storage'] = 							"storage";


//A HREF TAGS (links)
$lang['href_add'] =								"add a file";
$lang['href_list'] =							"return to list";
$lang['href_file_edit'] = 						"edit files";


//SUBMIT BUTTONS
$lang['sub_delete'] = 							"delete";
$lang['sub_upload'] = 							"upload";
$lang['sub_update'] = 							"update";
$lang['sub_update_default_image'] = 			"update default image";


//BODY TEXT
$lang['txt_add_file'] =							"By law you are not allowed to upload copyrighted material. Do not upload material that is offensive because you will end up looking stupid.";
$lang['txt_default_image'] = 					"default";
$lang['txt_edit_file'] =						"If you want to replace the file, select a new one. By law you are not allowed to upload copyrighted material. Do not upload material that is offensive because you will end up looking stupid.";
$lang['txt_file_name'] =						"file name";
$lang['txt_file_id'] =							"id";
$lang['txt_file_size'] =						"size";
$lang['txt_file_title'] =						"title";
$lang['txt_storage_allowed'] =					"total storage allowed";
$lang['txt_storage_total'] =					"total storage used";
$lang['txt_storage_no_add'] =					"your total storage allocation is used.";
$lang['txt_intro'] =							"You can upload images (png, jpg, gif), shockwave flash (swf), adobe acrobat (pdf) and plain text files.";

?>

==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/fil_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'fil_view.lang.php');

//HEADER
$lang['hdr_add_file'] = 						"add file";
$lang['hdr_files'] = 							"files";


//A HREF TAGS (links)
$lang['href_add'] =								"add a file";
$lang['href_list'] =							"return to list";
$lang['href_file_edit'] = 						"edit files";


//SUBMIT BUTTONS
$lang['sub_upload'] = 							"upload";
$lang['sub_update'] = 							"update";


//BODY TEXT
$lang['txt_add_file'] =							"By law you are not allowed to upload copyrighted material. Do not upload material that is offensive because you will end up looking stupid.";
$lang['txt_edit_file'] =						"If you want to replace the file, select a new one. By law you are not allowed to upload copyrighted material. Do not upload material that is offensive because you will end up looking stupid.";
$lang['txt_intro'] =							"You can upload images (png, jpg, gif), adobe acrobat (pdf) and plain text files.";
$lang['txt_file_title'] =						"title";

?>
